@@ -386,5 +386,5 @@ def ProcessFail(storage, parameter, msg):
         "file": "no data"
     }
 
-    print("merge failed")
+    print("process failed")
     return json.dumps(out_msg)
\ No newline at end of file
